/** EMULib Emulation Library *********************************/
/**                                                         **/
/**                      LibMSDOS.h                         **/
/**                                                         **/
/** This file contains MSDOS-dependent definitions and      **/
/** declarations for the emulation library.                 **/
/**                                                         **/
/** Copyright (C) Marat Fayzullin 1996-2007                 **/
/**     You are not allowed to distribute this software     **/
/**     commercially. Please, notify me, if you make any    **/
/**     changes to this file.                               **/
/*************************************************************/
#ifndef LIBMSDOS_H
#define LIBMSDOS_H
#ifdef __cplusplus
extern "C" {
#endif

#include "EMULib.h"

#define BPS8                /* Using 8bit sound on MSDOS     */

/** PIXEL() **************************************************/
/** MSDOS uses the 15bpp 5:5:5 pixel format.                **/
/*************************************************************/
#ifdef BPP16
#define PIXEL(R,G,B) (pixel)(((31*(R)/255)<<10)|((31*(G)/255)<<5)|(31*(B)/255))
#else
#define PIXEL(R,G,B) (pixel)(((7*(R)/255)<<5)|((7*(G)/255)<<2)|(3*(B)/255))
#endif

/** InitMSDOS() **********************************************/
/** Initialize MSDOS keyboard handler, etc.                 **/
/*************************************************************/
void InitMSDOS(void);

/** TrashMSDOS() *********************************************/
/** Restore MSDOS keyboard handler, etc.                    **/
/*************************************************************/
void TrashMSDOS(void);

/** InitAudio() **********************************************/
/** Initialize sound. Returns rate (Hz) on success, else 0. **/
/** Rate=0 to skip initialization (will be silent).         **/
/*************************************************************/
unsigned int InitAudio(unsigned int Rate,unsigned int Latency);

/** TrashAudio() *********************************************/
/** Free resources allocated by InitAudio().                **/
/*************************************************************/
void TrashAudio(void);

/** VGAWaitVBlank() ******************************************/
/** Wait VGA VBlank.                                        **/
/*************************************************************/
void VGAWaitVBlank(void);

/** VGAText80() **********************************************/
/** Set 80x25 text screenmode.                              **/
/*************************************************************/
void VGAText80(void);

/** VGA320x200() *********************************************/
/** Set 320x200x256 screenmode.                             **/
/*************************************************************/
void VGA320x200(void);

/** VGA800x600() *********************************************/
/** Set 800x600x256 screenmode.                             **/
/*************************************************************/
void VGA800x600(void);

/** VGA256x240() *********************************************/
/** Set 256x240x256 screenmode.                             **/
/*************************************************************/
void VGA256x240(void);

#ifdef __cplusplus
}
#endif
#endif /* LIBMSDOS_H */
